@@ -55,7 +55,7 @@ namespace bt
 	 */
 	class PeerManager : public TQObject
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 	public:
 		/**
