@@ -67,7 +67,7 @@ namespace bt
 	 */
 	class TorrentControl : public kt::TorrentInterface
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 	public:
 		TorrentControl();
