@@ -40,7 +40,7 @@ namespace bt
 	*/
 	class HTTPRequest : public kt::ExitOperation
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 	public:
 		/**
