@@ -41,7 +41,7 @@ namespace kt
 	*/
 	class InfoWidgetPlugin : public Plugin,public ViewListener
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 	public:
 		InfoWidgetPlugin(TQObject* parent, const char* name, const TQStringList& args);
